pilot.impl.pilotcompute_manager

Package pilot :: Package impl :: Module pilotcompute_manager |

# Module pilotcompute_manager

source code

PilotCompute Module: Implementation of PilotComputeService, PilotCompute, ComputeUnit.

Classes
| PilotComputeService PilotComputeService (PCS).
| PilotCompute Pilot Compute (PC).
| ComputeUnit ComputeUnit (CU).

Variables
| COORDINATION_URL = ``'``redis://localhost``'``
| __package__ = ``'``pilot.impl``'``